@@ -2,7 +2,7 @@
 # Copyright (c) The python-semanticversion project
 # This code is distributed under the two-clause BSD License.
 
-from .base import NpmSpec, Range, SimpleSpec, Version, compare, match, validate
+from .base import Range, SimpleSpec, Version, compare, match, validate
 
 __author__ = 'Raphaël Barrois <raphael.barrois+semver@polytechnique.org>'
 
@@ -11,7 +11,6 @@ __all__ = [
     'match',
     'validate',
     'SimpleSpec',
-    'NpmSpec',
     'Range',
     'Version',
 ]
