@@ -85,7 +85,7 @@ class Version(object):
         if has_text:
             major, minor, patch, revision, prerelease, build = self.parse(version_string)
         else:
-            revision = revision or 1
+            revision = revision or 0
             # Convenience: allow to omit prerelease/build.
             prerelease = tuple(prerelease or ())
             build = tuple(build or ())
@@ -134,6 +134,7 @@ class Version(object):
                 major=self.major,
                 minor=self.minor,
                 patch=self.patch,
+                revision=self.revision,
                 prerelease=self.prerelease,
             )
         elif level == 'patch':
@@ -189,7 +190,7 @@ class Version(object):
         if '~' in version:
             version, revision = version.split('~')
         else:
-            version, revision = version, '1'
+            version, revision = version, '0'
         revision = int(revision)
 
         while version.count('.') < 2:
@@ -266,9 +267,9 @@ class Version(object):
         major = int(major)
         minor = cls._coerce(minor)
         patch = cls._coerce(patch)
-        revision = int(revision) if revision else 1
-        if revision < 1:
-            raise ValueError('Invalid revision number, must be an integer greater or equal than 1')
+        revision = int(revision) if revision else 0
+        if revision < 0:
+            raise ValueError('Invalid revision number, must be an integer greater than or equal to 0')
 
         if not prerelease:
             prerelease = ()
@@ -429,27 +430,15 @@ class BaseSpec(object):
         AllOf(...),
     )
     """
-    SYNTAXES = {}  # type: dict[str, str]
-
-    @classmethod
-    def register_syntax(cls, subclass):
-        syntax = subclass.SYNTAX
-        if syntax is None:
-            raise ValueError('A Spec needs its SYNTAX field to be set.')
-        elif syntax in cls.SYNTAXES:
-            raise ValueError('Duplicate syntax for %s: %r, %r' % (syntax, cls.SYNTAXES[syntax], subclass))
-        cls.SYNTAXES[syntax] = subclass
-        return subclass
-
     def __init__(self, expression):
         super(BaseSpec, self).__init__()
         self.expression = expression
         self.clause = self._parse_to_clause(expression)
 
     @classmethod
-    def parse(cls, expression, syntax=DEFAULT_SYNTAX):
+    def parse(cls, expression):
         """Convert a syntax-specific expression into a BaseSpec instance."""
-        return cls.SYNTAXES[syntax](expression)
+        return cls(expression)
 
     @classmethod
     def _parse_to_clause(cls, expression):
@@ -815,11 +804,7 @@ class Range(Matcher):
         )
 
 
-@BaseSpec.register_syntax
 class SimpleSpec(BaseSpec):
-
-    SYNTAX = 'simple'
-
     @classmethod
     def _parse_to_clause(cls, expression):
         return cls.Parser.parse(expression)
@@ -830,6 +815,7 @@ class SimpleSpec(BaseSpec):
             r"""^
             (?P<op><|<=||=|==|>=|>|!=|\^|~|~=)
             (?P<major>{nb})(?:\.(?P<minor>{nb})(?:\.(?P<patch>{nb}))?)?
+            (?:~(?P<revision>\d+))?
             (?:-(?P<prerel>[a-z0-9A-Z.-]*))?
             (?:\+(?P<build>[a-z0-9A-Z.-]*))?
             $
@@ -869,12 +855,19 @@ class SimpleSpec(BaseSpec):
         def parse_block(cls, expr):
             if not cls.NAIVE_SPEC.match(expr):
                 raise ValueError('Invalid simple spec component: %r' % expr)
-            prefix, major_t, minor_t, patch_t, prerel, build = cls.NAIVE_SPEC.match(expr).groups()
+            prefix, major_t, minor_t, patch_t, revision, prerel, build = cls.NAIVE_SPEC.match(expr).groups()
             prefix = cls.PREFIX_ALIASES.get(prefix, prefix)
 
             major = None if major_t in cls.EMPTY_VALUES else int(major_t)
             minor = None if minor_t in cls.EMPTY_VALUES else int(minor_t)
             patch = None if patch_t in cls.EMPTY_VALUES else int(patch_t)
+            revision = None if revision in cls.EMPTY_VALUES else int(revision)
+
+            if (major is None or minor is None or patch is None) and (revision or prerel or build):
+                raise ValueError('Invalid simple spec: %r' % expr)
+
+            if build is not None and prefix not in (cls.PREFIX_EQ, cls.PREFIX_NEQ):
+                raise ValueError('Invalid simple spec: %r' % expr)
 
             if major is None:  # '*'
                 target = Version(major=0, minor=0, patch=0)
@@ -889,16 +882,11 @@ class SimpleSpec(BaseSpec):
                     major=major,
                     minor=minor,
                     patch=patch,
+                    revision=revision,
                     prerelease=prerel.split('.') if prerel else (),
                     build=build.split('.') if build else (),
                 )
 
-            if (major is None or minor is None or patch is None) and (prerel or build):
-                raise ValueError('Invalid simple spec: %r' % expr)
-
-            if build is not None and prefix not in (cls.PREFIX_EQ, cls.PREFIX_NEQ):
-                raise ValueError('Invalid simple spec: %r' % expr)
-
             if prefix == cls.PREFIX_CARET:
                 # Accept anything with the same most-significant digit
                 if target.major:
@@ -986,211 +974,3 @@ class SimpleSpec(BaseSpec):
                     return Range(Range.OP_LT, target.next_minor())
                 else:
                     return Range(Range.OP_LTE, target)
-
-
-@BaseSpec.register_syntax
-class NpmSpec(BaseSpec):
-    SYNTAX = 'npm'
-
-    @classmethod
-    def _parse_to_clause(cls, expression):
-        return cls.Parser.parse(expression)
-
-    class Parser:
-        JOINER = '||'
-        HYPHEN = ' - '
-
-        NUMBER = r'x|X|\*|0|[1-9][0-9]*'
-        PART = r'[a-zA-Z0-9.-]*'
-        NPM_SPEC_BLOCK = re.compile(
-            r"""
-            ^(?:v)?                     # Strip optional initial v
-            (?P<op><|<=|>=|>|=|\^|~|)   # Operator, can be empty
-            (?P<major>{nb})(?:\.(?P<minor>{nb})(?:\.(?P<patch>{nb}))?)?
-            (?:-(?P<prerel>{part}))?    # Optional re-release
-            (?:\+(?P<build>{part}))?    # Optional build
-            $""".format(nb=NUMBER, part=PART),
-            re.VERBOSE,
-        )
-
-        @classmethod
-        def range(cls, operator, target):
-            return Range(operator, target, prerelease_policy=Range.PRERELEASE_SAMEPATCH)
-
-        @classmethod
-        def parse(cls, expression):
-            result = Never()
-            groups = expression.split(cls.JOINER)
-            for group in groups:
-                group = group.strip()
-                if not group:
-                    group = '>=0.0.0'
-
-                subclauses = []
-                if cls.HYPHEN in group:
-                    low, high = group.split(cls.HYPHEN, 2)
-                    subclauses = cls.parse_simple('>=' + low) + cls.parse_simple('<=' + high)
-
-                else:
-                    blocks = group.split(' ')
-                    for block in blocks:
-                        if not cls.NPM_SPEC_BLOCK.match(block):
-                            raise ValueError('Invalid NPM block in %r: %r' % (expression, block))
-
-                        subclauses.extend(cls.parse_simple(block))
-
-                prerelease_clauses = []
-                non_prerel_clauses = []
-                for clause in subclauses:
-                    if clause.target.prerelease:
-                        if clause.operator in (Range.OP_GT, Range.OP_GTE):
-                            prerelease_clauses.append(
-                                Range(
-                                    operator=Range.OP_LT,
-                                    target=Version(
-                                        major=clause.target.major,
-                                        minor=clause.target.minor,
-                                        patch=clause.target.patch + 1,
-                                    ),
-                                    prerelease_policy=Range.PRERELEASE_ALWAYS,
-                                ))
-                        elif clause.operator in (Range.OP_LT, Range.OP_LTE):
-                            prerelease_clauses.append(
-                                Range(
-                                    operator=Range.OP_GTE,
-                                    target=Version(
-                                        major=clause.target.major,
-                                        minor=clause.target.minor,
-                                        patch=0,
-                                        prerelease=(),
-                                    ),
-                                    prerelease_policy=Range.PRERELEASE_ALWAYS,
-                                ))
-                        prerelease_clauses.append(clause)
-                        non_prerel_clauses.append(
-                            cls.range(
-                                operator=clause.operator,
-                                target=clause.target.truncate(),
-                            ))
-                    else:
-                        non_prerel_clauses.append(clause)
-                if prerelease_clauses:
-                    result |= AllOf(*prerelease_clauses)
-                result |= AllOf(*non_prerel_clauses)
-
-            return result
-
-        PREFIX_CARET = '^'
-        PREFIX_TILDE = '~'
-        PREFIX_EQ = '='
-        PREFIX_GT = '>'
-        PREFIX_GTE = '>='
-        PREFIX_LT = '<'
-        PREFIX_LTE = '<='
-
-        PREFIX_ALIASES = {
-            '': PREFIX_EQ,
-        }
-
-        PREFIX_TO_OPERATOR = {
-            PREFIX_EQ: Range.OP_EQ,
-            PREFIX_LT: Range.OP_LT,
-            PREFIX_LTE: Range.OP_LTE,
-            PREFIX_GTE: Range.OP_GTE,
-            PREFIX_GT: Range.OP_GT,
-        }
-
-        EMPTY_VALUES = ['*', 'x', 'X', None]
-
-        @classmethod
-        def parse_simple(cls, simple):
-            match = cls.NPM_SPEC_BLOCK.match(simple)
-
-            prefix, major_t, minor_t, patch_t, prerel, build = match.groups()
-
-            prefix = cls.PREFIX_ALIASES.get(prefix, prefix)
-            major = None if major_t in cls.EMPTY_VALUES else int(major_t)
-            minor = None if minor_t in cls.EMPTY_VALUES else int(minor_t)
-            patch = None if patch_t in cls.EMPTY_VALUES else int(patch_t)
-
-            if build is not None and prefix not in [cls.PREFIX_EQ]:
-                # Ignore the 'build' part when not comparing to a specific part.
-                build = None
-
-            if major is None:  # '*', 'x', 'X'
-                target = Version(major=0, minor=0, patch=0)
-                if prefix not in [cls.PREFIX_EQ, cls.PREFIX_GTE]:
-                    raise ValueError('Invalid expression %r' % simple)
-                prefix = cls.PREFIX_GTE
-            elif minor is None:
-                target = Version(major=major, minor=0, patch=0)
-            elif patch is None:
-                target = Version(major=major, minor=minor, patch=0)
-            else:
-                target = Version(
-                    major=major,
-                    minor=minor,
-                    patch=patch,
-                    prerelease=prerel.split('.') if prerel else (),
-                    build=build.split('.') if build else (),
-                )
-
-            if (major is None or minor is None or patch is None) and (prerel or build):
-                raise ValueError('Invalid NPM spec: %r' % simple)
-
-            if prefix == cls.PREFIX_CARET:
-                if target.major:  # ^1.2.4 => >=1.2.4 <2.0.0 ; ^1.x => >=1.0.0 <2.0.0
-                    high = target.truncate().next_major()
-                elif target.minor:  # ^0.1.2 => >=0.1.2 <0.2.0
-                    high = target.truncate().next_minor()
-                elif minor is None:  # ^0.x => >=0.0.0 <1.0.0
-                    high = target.truncate().next_major()
-                elif patch is None:  # ^0.2.x => >=0.2.0 <0.3.0
-                    high = target.truncate().next_minor()
-                else:  # ^0.0.1 => >=0.0.1 <0.0.2
-                    high = target.truncate().next_patch()
-                return [cls.range(Range.OP_GTE, target), cls.range(Range.OP_LT, high)]
-
-            elif prefix == cls.PREFIX_TILDE:
-                assert major is not None
-                if minor is None:  # ~1.x => >=1.0.0 <2.0.0
-                    high = target.next_major()
-                else:  # ~1.2.x => >=1.2.0 <1.3.0; ~1.2.3 => >=1.2.3 <1.3.0
-                    high = target.next_minor()
-                return [cls.range(Range.OP_GTE, target), cls.range(Range.OP_LT, high)]
-
-            elif prefix == cls.PREFIX_EQ:
-                if major is None:
-                    return [cls.range(Range.OP_GTE, target)]
-                elif minor is None:
-                    return [cls.range(Range.OP_GTE, target), cls.range(Range.OP_LT, target.next_major())]
-                elif patch is None:
-                    return [cls.range(Range.OP_GTE, target), cls.range(Range.OP_LT, target.next_minor())]
-                else:
-                    return [cls.range(Range.OP_EQ, target)]
-
-            elif prefix == cls.PREFIX_GT:
-                assert major is not None
-                if minor is None:  # >1.x
-                    return [cls.range(Range.OP_GTE, target.next_major())]
-                elif patch is None:  # >1.2.x => >=1.3.0
-                    return [cls.range(Range.OP_GTE, target.next_minor())]
-                else:
-                    return [cls.range(Range.OP_GT, target)]
-
-            elif prefix == cls.PREFIX_GTE:
-                return [cls.range(Range.OP_GTE, target)]
-
-            elif prefix == cls.PREFIX_LT:
-                assert major is not None
-                return [cls.range(Range.OP_LT, target)]
-
-            else:
-                assert prefix == cls.PREFIX_LTE
-                assert major is not None
-                if minor is None:  # <=1.x => <2.0.0
-                    return [cls.range(Range.OP_LT, target.next_major())]
-                elif patch is None:  # <=1.2.x => <1.3.0
-                    return [cls.range(Range.OP_LT, target.next_minor())]
-                else:
-                    return [cls.range(Range.OP_LTE, target)]
